@@ -1,26 +1,22 @@
 """Common Django module."""
 from pylint.checkers.base import NameChecker
-from pylint_django.augmentations import apply_augmentations
 from pylint_plugin_utils import get_checker
-import re
+
 from pylint_django.checkers import register_checkers
 
 # we want to import the transforms to make sure they get added to the astroid manager,
 # however we don't actually access them directly, so we'll disable the warning
-# pylint:disable=W0611
-from pylint_django import transforms
+from pylint_django import transforms  # noqa, pylint: disable=unused-import
 
 
 def register(linter):
-    """Registering additional checkers.
+    """
+    Registering additional checkers.
 
     However, we will also use it to amend existing checker config.
     """
     name_checker = get_checker(linter, NameChecker)
-    name_checker.config.good_names += ('qs',)
-    # Default pylint.checkers.base.CONST_NAME_RGX = re.compile('(([A-Z_][A-Z0-9_]*)|(__.*__))$').
-    const_rgx = '%s|(urls|urlpatterns|register)%s' % (name_checker.config.const_rgx.pattern[:-2], name_checker.config.const_rgx.pattern[-2:])
-    name_checker.config.const_rgx = re.compile(const_rgx)
+    name_checker.config.good_names += ('qs', 'urlpatterns', 'register', 'app_name', 'handler500')
 
     # we don't care about South migrations
     linter.config.black_list += ('migrations', 'south_migrations')
@@ -29,4 +25,10 @@ def register(linter):
     register_checkers(linter)
 
     # register any checking fiddlers
-    apply_augmentations(linter)
+    try:
+        from pylint_django.augmentations import apply_augmentations
+        apply_augmentations(linter)
+    except ModuleNotFoundError:
+        # probably trying to execute pylint_django when Django isn't installed
+        # in this case the django-not-installed checker will kick-in
+        pass
