@@ -26,7 +26,11 @@ def _add_transform(package_name, *class_names):
         if module.name != package_name:
             return
         for class_name in class_names:
-            module.locals[class_name] = fake.locals[class_name]
+            # This changed from locals to _locals between astroid 1.3 and 1.4
+            if hasattr(module, '_locals'):
+                module._locals[class_name].extend(fake._locals[class_name])  # pylint: disable=protected-access
+            else:
+                module.locals[class_name].extend(fake.locals[class_name])
 
     MANAGER.register_transform(nodes.Module, set_fake_locals)
 
@@ -39,3 +43,4 @@ _add_transform('django.db.models',
                'Model',
                'Manager')
 _add_transform('django.utils.translation', 'ugettext_lazy')
+_add_transform('mongoengine', 'Document')
