@@ -1,14 +1,16 @@
-from astroid import nodes, InferenceError, inference_tip, UseInferenceDefault
+from astroid import MANAGER, nodes, InferenceError, inference_tip, UseInferenceDefault
+from pylint_django.utils import node_is_subclass
+from pylint_django.compat import ClassDef, instantiate_class, Attribute
 
 
 def is_foreignkey_in_class(node):
     # is this of the form  field = models.ForeignKey
     if not isinstance(node.parent, nodes.Assign):
         return False
-    if not isinstance(node.parent.parent, nodes.Class):
+    if not isinstance(node.parent.parent, ClassDef):
         return False
 
-    if isinstance(node.func, nodes.Getattr):
+    if isinstance(node.func, Attribute):
         attr = node.func.attrname
     elif isinstance(node.func, nodes.Name):
         attr = node.func.name
@@ -32,9 +34,24 @@ def infer_key_classes(node, context=None):
             else:
                 if key_cls is not None:
                     break
+        elif isinstance(arg, nodes.Const):
+            try:
+                model_name = arg.value.split('.')[-1]  # can be 'Model' or 'app.Model'
+            except AttributeError:
+                break
+
+            for module in MANAGER.astroid_cache.values():
+                if model_name in module.locals:
+                    class_defs = [
+                        module_node for module_node in module.lookup(model_name)[1]
+                        if isinstance(module_node, nodes.ClassDef)
+                        and node_is_subclass(module_node, 'django.db.models.base.Model')
+                    ]
+                    if class_defs:
+                        return iter([instantiate_class(class_defs[0])()])
     else:
         raise UseInferenceDefault
-    return iter([key_cls.instanciate_class()])
+    return iter([instantiate_class(key_cls)()])
 
 
 def add_transform(manager):
