@@ -11,10 +11,11 @@ class Form(BaseForm):
 
 
 class ModelForm(BaseModelForm):
-    save_m2m = lambda: None
+    def save_m2m(self):
+        return None
     cleaned_data = None
     fields = None
     instance = None
     data = None
     _errors = None
-    base_fields = None
\ No newline at end of file
+    base_fields = None
