@@ -1,8 +1,7 @@
-
 class View(object):
     request = None
-    args = None
-    kwargs = None
+    args = ()
+    kwargs = {}
 
     # as_view is marked as class-only
     def as_view(*args, **kwargs):
